# python-osism

[![Quay](https://img.shields.io/badge/Quay-osism%2Fosism-blue.svg)](https://quay.io/repository/osism/osism)

## Total overview

![osism](https://raw.githubusercontent.com/osism/python-osism/main/contrib/osism.drawio.png)

### Detailed overview

![python-osism](https://raw.githubusercontent.com/osism/python-osism/main/contrib/python-osism.drawio.png)
